# Table of Contents

- [configuring-sap-btp-cloud-foundry-integration-using-trusted-certificate-authentication](<./configuring-sap-btp-cloud-foundry-integration-using-trusted-certificate-authentication.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring SAP BTP, Cloud Foundry Integration Using Trusted Certificate Authentication](<./Configuring-SAP-BTP-Cloud-Foundry-Integration-Using-Trusted-Certificate-Authentication.md>)
  - [Overview](<./Configuring-SAP-BTP-Cloud-Foundry-Integration-Using-Trusted-Certificate-Authentication/Overview.md>)
  - [Prerequisites](<./Configuring-SAP-BTP-Cloud-Foundry-Integration-Using-Trusted-Certificate-Authentication/Prerequisites.md>)
  - [Step 1: Create or Verify the IAS Platform User](<./Configuring-SAP-BTP-Cloud-Foundry-Integration-Using-Trusted-Certificate-Authentication/Step-1-Create-or-Verify-the-IAS-Platform-User.md>)
  - [Step 2: Create an SAP Cloud Management Service Instance and Service Key](<./Configuring-SAP-BTP-Cloud-Foundry-Integration-Using-Trusted-Certificate-Authentication/Step-2-Create-an-SAP-Cloud-Management-Service-Instance-and-Service-Key.md>)
  - [Step 3: Add the Platform User to SAP BTP, Cloud Foundry Organizations and Spaces](<./Configuring-SAP-BTP-Cloud-Foundry-Integration-Using-Trusted-Certificate-Authentication/Step-3-Add-the-Platform-User-to-SAP-BTP-Cloud-Foundry-Organizations-and-Spaces.md>)
  - [Step 4: Connect LeanIX to SAP BTP, Cloud Foundry](<./Configuring-SAP-BTP-Cloud-Foundry-Integration-Using-Trusted-Certificate-Authentication/Step-4-Connect-LeanIX-to-SAP-BTP-Cloud-Foundry.md>)
  - [Troubleshooting](<./Configuring-SAP-BTP-Cloud-Foundry-Integration-Using-Trusted-Certificate-Authentication/Troubleshooting.md>)
  - [We'd love your feedback!](<./Configuring-SAP-BTP-Cloud-Foundry-Integration-Using-Trusted-Certificate-Authentication/Wed-love-your-feedback.md>)
